@@ -1,6 +1,6 @@
 package Mason::Interp;
 BEGIN {
-  $Mason::Interp::VERSION = '2.16';
+  $Mason::Interp::VERSION = '2.17';
 }
 use Carp;
 use Devel::GlobalDestruction;
@@ -435,7 +435,7 @@ method _load_class_from_object_file ( $compc, $object_file, $path, $default_pare
       || ( $default_parent_path eq '/' && $self->component_class )
       || $self->load($default_parent_path);
 
-    my $code = sprintf( 'package %s; use Moose; extends "%s"; do("%s"); die $@ if $@',
+    my $code = sprintf( 'package %s; use Moose; extends \'%s\'; do(\'%s\'); die $@ if $@',
         $compc, $parent_compc, $object_file );
     ($code) = ( $code =~ /^(.*)/s ) if taint_is_on();
     eval($code);
